# Band Manager

<div align="center">
  <img src="img/deklittenband_logo.png" alt="De Klittenband logo" width="80%">
</div>


| [**GitHub**](https://github.com/mpvanderschelling/bandmanager)
| [**Documentation**](https://bandmanager.readthedocs.io/en/latest/)
|

Application to create invoices, quotations and contracts for bands.

**First publication:** January 3, 2026

***

## Summary

<!-- Write here a longer description of the package, what it does, and why it is useful. -->

## Statement of need

<!-- Write here the statement of need for this package -->

## Authorship

**Authors**:
- Martin van der Schelling ([martin@vanderschelling.com](mailto:martin@vanderschelling.com))

**Maintainer:**
- Martin van der Schelling ([martin@vanderschelling.com](mailto:martin@vanderschelling.com))


## Getting started

<!-- Write here how users should get started with this package -->

## Community Support

If you find any **issues, bugs or problems** with this package, please use the [GitHub issue tracker](https://github.com/mpvanderschelling/bandmanager/issues) to report them.

## License

Copyright (c) 2026, Martin van der Schelling

All rights reserved.

This project is licensed under the BSD 3-Clause License. See [LICENSE](https://github.com/mpvanderschelling/bandmanager/blob/main/LICENSE) for the full license text.

